@@ -1,3 +1,4 @@
+from upswingutil.pms import store_reservation_to_alvie
 from upswingutil.pms.oracle import NAME, get_key, validate_key
 from upswingutil.db import Mongodb, MongodbV2
 from upswingutil.schema import Token
@@ -596,6 +597,7 @@ class ReservationSync:
             record = self._extract_reservation_details(record)
             record = self._transform_reservation(record)
             self.mongoV2.save(record)
+            store_reservation_to_alvie(record)
 
     def __del__(self):
         logging.info(f'API calls made: {self._api_call_counter}')
