@@ -6,7 +6,7 @@ from pydantic import BaseModel
 class ResponseList(BaseModel):
     status: bool = False
     message: str = 'default error msg'
-    data: List[dict] = []
+    data: List = []
 
 
 class ResponseDict(BaseModel):
